require "spec_helper"

describe Slack::RPC::Client do

	before do
		@base_url = "https://slack.com/api/api.test"
	end

	it "should have requested with Accept header" do
		stub = stub_request(:get, @base_url)
		client = Slack::RPC::Client.new()
		client.api.test()
		expect(stub.
			with(:headers => {"Accept" => "application/json"})).to have_been_made
	end

	it "should have requested with User-Agent header" do
		stub = stub_request(:get, @base_url)
		client = Slack::RPC::Client.new()
		client.api.test()
		expect(stub.
			with(:headers => {"User-Agent" => "Slack Ruby Gem #{Slack::VERSION}"})).to have_been_made
	end

	it "should have requested with URL-encoded query parameter" do
		stub = stub_request(:get, @base_url).with(:query => {"foo" => "this is test & spec"})
		client = Slack::RPC::Client.new()
		client.api.test(:foo => "this is test & spec")
		expect(stub).to have_been_made
	end

	it "can set token at initialization" do
		client = Slack::RPC::Client.new("0123456789")
		expect(client.token).to eq("0123456789")
	end

	it "can set token after initialization" do
		client = Slack::RPC::Client.new()
		expect(client.token).to eq(nil)
		client.token = "0123456789"
		expect(client.token).to eq("0123456789")
	end

	it "can get token" do
		client = Slack::RPC::Client.new("0123456789")
		expect(client.token).to eq("0123456789")
	end

	context "with token" do
		it "should have requested with token" do
			stub = stub_request(:get, @base_url).with(:query => {"token" => "0123456789"})
			client = Slack::RPC::Client.new("0123456789")
			client.api.test()
			expect(stub).to have_been_made
		end
	end

	context "without token" do
		it "should have requested without token" do
			stub = stub_request(:get, @base_url)
			client = Slack::RPC::Client.new()
			client.api.test()
			expect(stub).to have_been_made
		end
	end

end
